=======
Credits
=======

Development Lead
----------------

* GoTLiuM InSPiRiT (`gotlium <https://github.com/gotlium>`_)

Contributors
------------

* Sergey Nikitin (`nikitinsm <https://github.com/nikitinsm>`_)
* Volodymyr Tartynskyi (`vosi <https://github.com/vosi>`_)
* Petr Zelenin (`petrikoz <https://github.com/petrikoz>`_)
* icegreg (`icegreg <https://github.com/icegreg>`_)
